@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -15,11 +15,11 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include "customtoolsplugin.h"
-
-#include "customtoolsviewinterface.h"
 #include "customtoolswidgetng.h"
-#include "customtools/customtoolspluginmanager.h"
+#include "customtoolsplugin.h"
+#include "customtoolspluginmanager.h"
+#include "customtoolsviewinterface.h"
+
 #include <KToggleAction>
 
 #include <QHBoxLayout>
@@ -31,17 +31,16 @@ class PimCommon::CustomToolsWidgetNgPrivate
 {
 public:
     CustomToolsWidgetNgPrivate()
-        : mStackedWidget(nullptr)
     {
-
     }
-    QStackedWidget *mStackedWidget;
+
+    QStackedWidget *mStackedWidget = nullptr;
     QList<PimCommon::CustomToolsViewInterface *> mListInterfaceView;
 };
 
 CustomToolsWidgetNg::CustomToolsWidgetNg(KActionCollection *ac, QWidget *parent)
-    : QWidget(parent),
-      d(new PimCommon::CustomToolsWidgetNgPrivate)
+    : QWidget(parent)
+    , d(new PimCommon::CustomToolsWidgetNgPrivate)
 {
     QHBoxLayout *lay = new QHBoxLayout(this);
     d->mStackedWidget = new QStackedWidget;
