@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -31,10 +31,9 @@ class PimCommon::MigrateApplicationFilesPrivate
 {
 public:
     MigrateApplicationFilesPrivate()
-        : mMigrateApplicationVersion(1),
-          mCurrentConfigVersion(0)
+        : mMigrateApplicationVersion(1)
+        , mCurrentConfigVersion(0)
     {
-
     }
 
     QVector<MigrateFileInfo> mMigrateInfoList;
@@ -46,10 +45,9 @@ public:
 };
 
 MigrateApplicationFiles::MigrateApplicationFiles(QObject *parent)
-    : QObject(parent),
-      d(new PimCommon::MigrateApplicationFilesPrivate)
+    : QObject(parent)
+    , d(new PimCommon::MigrateApplicationFilesPrivate)
 {
-
 }
 
 MigrateApplicationFiles::~MigrateApplicationFiles()
@@ -259,4 +257,3 @@ void MigrateApplicationFiles::insertMigrateInfo(const MigrateFileInfo &info)
         d->mMigrateInfoList.append(info);
     }
 }
-
