@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,6 +24,7 @@
 #include <KLocalizedString>
 #include <QMenu>
 #include <KNS3/DownloadDialog>
+#include <KAuthorized>
 #include <QIcon>
 
 #include <QListWidgetItem>
@@ -32,16 +33,17 @@
 #include <QDropEvent>
 #include <QFileDialog>
 
-namespace PimCommon
-{
-
+namespace PimCommon {
 class TemplateListWidgetPrivate
 {
 public:
     TemplateListWidgetPrivate(const QString &configName, TemplateListWidget *qq)
-        : dirty(false), config(KSharedConfig::openConfig(configName, KConfig::NoGlobals)), q(qq)
+        : dirty(false)
+        , config(KSharedConfig::openConfig(configName, KConfig::NoGlobals))
+        , q(qq)
     {
     }
+
     ~TemplateListWidgetPrivate()
     {
         save();
@@ -141,7 +143,7 @@ public:
 
     void slotImportTemplates()
     {
-        const QString templateFile = QFileDialog::getOpenFileName(q);
+        const QString templateFile = QFileDialog::getOpenFileName(q, i18n("Import Template"));
         if (!templateFile.isEmpty()) {
             KConfig conf(templateFile, KConfig::SimpleConfig);
             loadTemplates(&conf);
@@ -150,7 +152,7 @@ public:
 
     void slotExportTemplates()
     {
-        const QString templateFile = QFileDialog::getSaveFileName(q);
+        const QString templateFile = QFileDialog::getSaveFileName(q, i18n("Export Template"));
         if (!templateFile.isEmpty()) {
             KConfig conf(templateFile, KConfig::SimpleConfig);
             saveTemplates(&conf);
@@ -164,32 +166,49 @@ public:
         QMenu *menu = new QMenu(q);
 
         if (!listSelectedIsEmpty) {
-            menu->addAction(i18n("Insert template"), q, SLOT(slotInsertTemplate()));
+            menu->addAction(i18n("Insert template"), q, [this]() {
+                    slotInsertTemplate();
+                });
             menu->addSeparator();
         }
 
-        menu->addAction(i18n("Add..."), q, SLOT(slotAdd()));
+        menu->addAction(i18n("Add..."), q, [this]() {
+                slotAdd();
+            });
         if (!listSelectedIsEmpty) {
             const bool defaultTemplate = lstSelectedItems.first()->data(TemplateListWidget::DefaultTemplate).toBool();
             if (lstSelectedItems.count() == 1) {
-                menu->addAction(defaultTemplate ? i18n("Show...") : i18n("Modify..."), q, SLOT(slotModify()));
-                menu->addAction(i18n("Duplicate"), q, SLOT(slotDuplicate()));
+                menu->addAction(defaultTemplate ? i18n("Show...") : i18n("Modify..."), q, [this]() {
+                        slotModify();
+                    });
+                menu->addAction(i18n("Duplicate"), q, [this]() {
+                        slotDuplicate();
+                    });
             }
             if (lstSelectedItems.count() == 1 && !defaultTemplate) {
                 menu->addSeparator();
-                menu->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove"), q, SLOT(slotRemove()));
+                menu->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove"), q, [this]() {
+                        slotRemove();
+                    });
             }
         }
         menu->addSeparator();
         if (q->count() > 0) {
-            menu->addAction(i18n("Export..."), q, SLOT(slotExportTemplates()));
+            menu->addAction(i18n("Export..."), q, [this]() {
+                    slotExportTemplates();
+                });
         }
-        menu->addAction(i18n("Import..."), q, SLOT(slotImportTemplates()));
+        menu->addAction(i18n("Import..."), q, [this]() {
+                slotImportTemplates();
+            });
 
-        if (!knewstuffConfigName.isEmpty()) {
-            menu->addSeparator();
-            QAction *act = menu->addAction(i18n("Download new Templates..."), q, SLOT(slotDownloadTemplates()));
-            act->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
+        if (KAuthorized::authorize(QStringLiteral("ghns"))) {
+            if (!knewstuffConfigName.isEmpty()) {
+                menu->addSeparator();
+                menu->addAction(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")), i18n("Download new Templates..."), q, [this]() {
+                        slotDownloadTemplates();
+                    });
+            }
         }
 
         menu->exec(q->mapToGlobal(pos));
@@ -230,7 +249,8 @@ public:
     void saveTemplates(KConfig *configFile)
     {
         // clear everything
-        for (const QString &group : configFile->groupList()) {
+        const QStringList lst = configFile->groupList();
+        for (const QString &group : lst) {
             configFile->deleteGroup(group);
         }
         int numberOfTemplate = 0;
@@ -264,6 +284,7 @@ public:
         saveTemplates(config.data());
         dirty = false;
     }
+
     QString knewstuffConfigName;
     bool dirty;
     KSharedConfig::Ptr config;
@@ -271,15 +292,21 @@ public:
 };
 
 TemplateListWidget::TemplateListWidget(const QString &configName, QWidget *parent)
-    : QListWidget(parent), d(new TemplateListWidgetPrivate(configName, this))
+    : QListWidget(parent)
+    , d(new TemplateListWidgetPrivate(configName, this))
 {
     setContextMenuPolicy(Qt::CustomContextMenu);
     setDragDropMode(QAbstractItemView::DragDrop);
 
-    connect(this, SIGNAL(customContextMenuRequested(QPoint)),
-            SLOT(slotContextMenu(QPoint)));
-    connect(this, SIGNAL(doubleClicked(QModelIndex)), SLOT(slotModify()));
-    connect(this, SIGNAL(insertNewTemplate(QString)), SLOT(slotInsertNewTemplate(QString)));
+    connect(this, &TemplateListWidget::customContextMenuRequested, this, [this](const QPoint &p) {
+            d->slotContextMenu(p);
+        });
+    connect(this, &TemplateListWidget::doubleClicked, this, [this]() {
+            d->slotModify();
+        });
+    connect(this, &TemplateListWidget::insertNewTemplate, this, [this](const QString &tmp) {
+            d->slotInsertNewTemplate(tmp);
+        });
 }
 
 TemplateListWidget::~TemplateListWidget()
@@ -299,7 +326,9 @@ QVector<defaultTemplate> TemplateListWidget::defaultTemplates()
 
 QStringList TemplateListWidget::mimeTypes() const
 {
-    const QStringList lst{QStringLiteral("text/plain")};
+    const QStringList lst{
+        QStringLiteral("text/plain")
+    };
     return lst;
 }
 
@@ -367,6 +396,4 @@ void TemplateListWidget::addDefaultTemplate(const QString &templateName, const Q
 {
     d->createListWidgetItem(templateName, templateScript, true);
 }
-
 }
-#include "moc_templatelistwidget.cpp"
