@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -32,22 +32,25 @@ class PimCommon::PluginInterfacePrivate
 {
 public:
     PluginInterfacePrivate()
-        : mParentWidget(nullptr),
-          mActionCollection(nullptr)
+        : mParentWidget(nullptr)
+        , mActionCollection(nullptr)
+        , mGenericPluginManager(nullptr)
     {
-
     }
+
     QString mPluginName;
     QString mServiceTypeName;
-    QWidget *mParentWidget;
-    KActionCollection *mActionCollection;
+    QWidget *mParentWidget = nullptr;
+    KActionCollection *mActionCollection = nullptr;
     QVector<PimCommon::GenericPluginInterface *> mListGenericInterface;
+    GenericPluginManager *mGenericPluginManager = nullptr;
 };
 
 PluginInterface::PluginInterface(QObject *parent)
-    : QObject(parent),
-      d(new PimCommon::PluginInterfacePrivate)
+    : QObject(parent)
+    , d(new PimCommon::PluginInterfacePrivate)
 {
+    d->mGenericPluginManager = new GenericPluginManager(this);
 }
 
 PluginInterface::~PluginInterface()
@@ -62,9 +65,9 @@ void PimCommon::PluginInterface::setActionCollection(KActionCollection *ac)
 
 void PluginInterface::initializePlugins()
 {
-    PimCommon::GenericPluginManager::self()->setPluginName(d->mPluginName);
-    PimCommon::GenericPluginManager::self()->setServiceTypeName(d->mServiceTypeName);
-    if (!PimCommon::GenericPluginManager::self()->initializePlugins()) {
+    d->mGenericPluginManager->setPluginName(d->mPluginName);
+    d->mGenericPluginManager->setServiceTypeName(d->mServiceTypeName);
+    if (!d->mGenericPluginManager->initializePlugins()) {
         qCDebug(PIMCOMMONAKONADI_LOG) << " Impossible to initialize plugins";
     }
 }
@@ -85,7 +88,7 @@ void PluginInterface::createPluginInterface()
         qCWarning(PIMCOMMONAKONADI_LOG) << "Missing action collection";
         return;
     }
-    Q_FOREACH (PimCommon::GenericPlugin *plugin, PimCommon::GenericPluginManager::self()->pluginsList()) {
+    Q_FOREACH (PimCommon::GenericPlugin *plugin, d->mGenericPluginManager->pluginsList()) {
         if (plugin->isEnabled()) {
             PimCommon::GenericPluginInterface *interface = static_cast<PimCommon::GenericPluginInterface *>(plugin->createInterface(d->mActionCollection, this));
             interface->setParentWidget(d->mParentWidget);
@@ -116,6 +119,10 @@ QString PluginInterface::actionXmlExtension(ActionType::Type type)
         return QStringLiteral("_popupmenu_actions");
     case PimCommon::ActionType::ToolBar:
         return QStringLiteral("_toolbar_actions");
+    case PimCommon::ActionType::Message:
+        return QStringLiteral("_plugins_message");
+    case PimCommon::ActionType::Folder:
+        return QStringLiteral("_plugins_folder");
     }
     return {};
 }
@@ -160,19 +167,8 @@ QHash<PimCommon::ActionType::Type, QList<QAction *> > PluginInterface::actionsTy
 {
     QHash<PimCommon::ActionType::Type, QList<QAction *> > listType;
     for (PimCommon::GenericPluginInterface *interface : qAsConst(d->mListGenericInterface)) {
-        PimCommon::ActionType actionType = interface->actionType();
-        PimCommon::ActionType::Type type = actionType.type();
-        QList<QAction *> lst = listType.value(type);
-        if (!lst.isEmpty()) {
-            QAction *act = new QAction(this);
-            act->setSeparator(true);
-            lst << act << actionType.action();
-            listType.insert(type, lst);
-        } else {
-            listType.insert(type, QList<QAction *>() << actionType.action());
-        }
-        if (interface->plugin()->hasPopupMenuSupport()) {
-            type = PimCommon::ActionType::PopupMenu;
+        for (const PimCommon::ActionType &actionType : interface->actionTypes()) {
+            PimCommon::ActionType::Type type = actionType.type();
             QList<QAction *> lst = listType.value(type);
             if (!lst.isEmpty()) {
                 QAction *act = new QAction(this);
@@ -182,17 +178,29 @@ QHash<PimCommon::ActionType::Type, QList<QAction *> > PluginInterface::actionsTy
             } else {
                 listType.insert(type, QList<QAction *>() << actionType.action());
             }
-        }
-        if (interface->plugin()->hasToolBarSupport()) {
-            type = PimCommon::ActionType::ToolBar;
-            QList<QAction *> lst = listType.value(type);
-            if (!lst.isEmpty()) {
-                QAction *act = new QAction(this);
-                act->setSeparator(true);
-                lst << act << actionType.action();
-                listType.insert(type, lst);
-            } else {
-                listType.insert(type, QList<QAction *>() << actionType.action());
+            if (interface->plugin()->hasPopupMenuSupport()) {
+                type = PimCommon::ActionType::PopupMenu;
+                QList<QAction *> lst = listType.value(type);
+                if (!lst.isEmpty()) {
+                    QAction *act = new QAction(this);
+                    act->setSeparator(true);
+                    lst << act << actionType.action();
+                    listType.insert(type, lst);
+                } else {
+                    listType.insert(type, QList<QAction *>() << actionType.action());
+                }
+            }
+            if (interface->plugin()->hasToolBarSupport()) {
+                type = PimCommon::ActionType::ToolBar;
+                QList<QAction *> lst = listType.value(type);
+                if (!lst.isEmpty()) {
+                    QAction *act = new QAction(this);
+                    act->setSeparator(true);
+                    lst << act << actionType.action();
+                    listType.insert(type, lst);
+                } else {
+                    listType.insert(type, QList<QAction *>() << actionType.action());
+                }
             }
         }
     }
@@ -202,20 +210,20 @@ QHash<PimCommon::ActionType::Type, QList<QAction *> > PluginInterface::actionsTy
 
 QVector<PimCommon::PluginUtilData> PluginInterface::pluginsDataList() const
 {
-    return GenericPluginManager::self()->pluginsDataList();
+    return d->mGenericPluginManager->pluginsDataList();
 }
 
 QString PluginInterface::configGroupName() const
 {
-    return GenericPluginManager::self()->configGroupName();
+    return d->mGenericPluginManager->configGroupName();
 }
 
 QString PluginInterface::configPrefixSettingKey() const
 {
-    return GenericPluginManager::self()->configPrefixSettingKey();
+    return d->mGenericPluginManager->configPrefixSettingKey();
 }
 
 PimCommon::GenericPlugin *PluginInterface::pluginFromIdentifier(const QString &id)
 {
-    return GenericPluginManager::self()->pluginFromIdentifier(id);
+    return d->mGenericPluginManager->pluginFromIdentifier(id);
 }
